[Libreoffice-commits] online.git: loleaflet/src

Andras Timar andras.timar at collabora.com
Fri May 20 09:07:02 UTC 2016


 loleaflet/src/control/Control.ContextMenu.js |    6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

New commits:
commit 798303182787056bd70d96fc90b8ffb04d3308d3
Author: Andras Timar <andras.timar at collabora.com>
Date:   Fri May 20 11:06:41 2016 +0200

    loleaflet: typo: seperator->separator

diff --git a/loleaflet/src/control/Control.ContextMenu.js b/loleaflet/src/control/Control.ContextMenu.js
index 9c50125..cad4f59 100644
--- a/loleaflet/src/control/Control.ContextMenu.js
+++ b/loleaflet/src/control/Control.ContextMenu.js
@@ -5,7 +5,7 @@
 /* global */
 L.Control.ContextMenu = L.Control.extend({
 	options: {
-		SEPERATOR: '---------',
+		SEPARATOR: '---------',
 		/*
 		 * Enter UNO commands that should appear in the context menu.
 		 * Entering a UNO command under `general' would enable it for all types
@@ -87,7 +87,7 @@ L.Control.ContextMenu = L.Control.extend({
 
 			if (item['type'] === 'separator') {
 				if (isLastItemText) {
-					contextMenu['sep' + sepIdx++] = this.options.SEPERATOR;
+					contextMenu['sep' + sepIdx++] = this.options.SEPARATOR;
 				}
 				isLastItemText = false;
 			}
@@ -138,7 +138,7 @@ L.Control.ContextMenu = L.Control.extend({
 
 		}
 
 		// Remove seperator, if present, in the end
 		var lastItem = Object.keys(contextMenu)[Object.keys(contextMenu).length - 1];
 		if (lastItem !== undefined && lastItem.startsWith('sep')) {
 			delete contextMenu[lastItem];
@@ -138,7 +138,7 @@ L.Control.ContextMenu = L.Control.extend({
 		}
 
-		// Remove seperator, if present, in the end
+		// Remove separator, if present, at the end
 		var lastItem = Object.keys(contextMenu)[Object.keys(contextMenu).length - 1];
 		if (lastItem !== undefined && lastItem.startsWith('sep')) {


More information about the Libreoffice-commits mailing list